This geom acts like ggplot2::geom_point(), except that the specified
silhouettes are used as points. Silhouettes can be specified by their name,
uuid, or image objects (img).
geom_phylopic(
mapping = NULL,
data = NULL,
stat = "identity",
position = "identity",
...,
na.rm = FALSE,
show.legend = FALSE,
inherit.aes = TRUE,
remove_background = TRUE,
verbose = FALSE,
filter = NULL
)Set of aesthetic mappings created by aes(). If specified and
inherit.aes = TRUE (the default), it is combined with the default mapping
at the top level of the plot. You must supply mapping if there is no plot
mapping.
The data to be displayed in this layer. There are three options:
If NULL, the default, the data is inherited from the plot
data as specified in the call to ggplot().
A data.frame, or other object, will override the plot
data. All objects will be fortified to produce a data frame. See
fortify() for which variables will be created.
A function will be called with a single argument,
the plot data. The return value must be a data.frame, and
will be used as the layer data. A function can be created
from a formula (e.g. ~ head(.x, 10)).
The statistical transformation to use on the data for this
layer, either as a ggproto Geom subclass or as a string naming the
stat stripped of the stat_ prefix (e.g. "count" rather than
"stat_count")
Position adjustment, either as a string naming the adjustment
(e.g. "jitter" to use position_jitter), or the result of a call to a
position adjustment function. Use the latter if you need to change the
settings of the adjustment.
Other arguments passed on to layer(). These are
often aesthetics, used to set an aesthetic to a fixed value, like
colour = "red" or size = 3. They may also be parameters
to the paired geom/stat.
If FALSE, the default, missing values are removed with
a warning. If TRUE, missing values are silently removed.
logical. Should this layer be included in the legends?
FALSE, the default, never includes, NA includes if any aesthetics are
mapped, and TRUE always includes. It can also be a named logical vector
to finely select the aesthetics to display.
If FALSE, overrides the default aesthetics,
rather than combining with them. This is most useful for helper functions
that define both data and aesthetics and shouldn't inherit behaviour from
the default plot specification, e.g. borders().
logical. Should any white background be
removed from the silhouette(s)? See recolor_phylopic() for details.
logical. Should the attribution information for the
used silhouette(s) be printed to the console (see get_attribution())?
character. Filter by usage license if using the name
aesthetic. Use "by" to limit results to images which do not require
attribution, "nc" for images which allows commercial usage, and "sa" for
images without a ShareAlike clause. The user can also combine these filters
as a vector.
geom_phylopic understands the following aesthetics:
x (required)
y (required)
img/uuid/name (one, and only one, required)
size
color/colour
fill
alpha
horizontal
vertical
angle
Learn more about setting these aesthetics in add_phylopic().
One (and only one) of the img, name, or uuid aesthetics must
be specified. The img aesthetic can be
Picture objects or png array objects, e.g.,
from using get_phylopic(). Use the x and y aesthetics to place the
silhouettes at specified positions on the plot. The size aesthetic
specifies the height of the silhouettes in the units of the y axis. The
aspect ratio of the silhouettes will always be maintained.
The color (default: NA), fill (default: "black"), and alpha (
default: 1) aesthetics can be used to change the outline color, fill color,
and transparency (outline and fill) of the silhouettes, respectively. If
color is specified and fill is NA color will be used as the fill
color (for backwards compatibility). If "original" is specified for the
color aesthetic, the original color of the silhouette outline will be
used (usually the same as "transparent"). If "original" is specified for
the fill aesthetic, the original color of the silhouette body will be
used (usually the same as "black"). To remove the fill or outline, you can
set fill or color to "transparent", respectively.
The horizontal and vertical aesthetics can be used to flip the
silhouettes. The angle aesthetic can be used to rotate the silhouettes.
When specifying a horizontal and/or vertical flip and a rotation, the
flip(s) will always occur first. If you would like to customize this
behavior, you can flip and/or rotate the image within your own workflow
using flip_phylopic() and rotate_phylopic().
Note that png array objects can only be rotated by multiples of 90 degrees. Also, outline colors do not currently work for png array objects.
if (FALSE) {
library(ggplot2)
df <- data.frame(x = c(2, 4), y = c(10, 20),
name = c("Felis silvestris catus", "Odobenus rosmarus"))
ggplot(df) +
geom_phylopic(aes(x = x, y = y, name = name),
fill = "purple", size = 10) +
facet_wrap(~name) +
coord_cartesian(xlim = c(1,6), ylim = c(5, 30))
}
Run the code above in your browser using DataLab