Learn R Programming

rphylopic (version 0.1.9.9321)

minimal_supertaxa: Finds the minimal common supertaxa for a list of names.

Description

Finds the minimal common supertaxa for a list of names.

Usage

minimal_supertaxa(nameUIDs, options = NULL, ...)

Arguments

nameUIDs

Space-separated list of UUIDs for taxonomic names.

options

Space-separated list of options for the result value.

...

Further args passed on to GET. See examples.

Details

Here are the options for the options argument:

  • citationStart: (optional) Integer Indicates where in the string the citation starts. May be null.

  • html: (optional) StringHTML version of the name.

  • namebankID: (optional) StringuBio Namebank identifier. May be null.

  • root: (optional) Boolean If true, this name has no hyperonyms (names of supertaxa). (Should only be true for Panbiota/Vitae.)

  • string: (optional) String The text of the name, including the citation, if any.

  • type: (optional) String Either "scientific or "vernacular.

  • uid: (always) String Universally unique identifier.

  • uri: (optional) String The unique URI associated with the name.

  • votes: (optional) Integer The number of votes this name has received. (Currently unused.)

Examples

Run this code
# NOT RUN {
minimal_supertaxa(nameUIDs=c("1ee65cf3-53db-4a52-9960-a9f7093d845d", 
   "08141cfc-ef1f-4d0e-a061-b1347f5297a0"))
# }

Run the code above in your browser using DataLab